*cd "" 
use "data/chinadata.dta", replace

*Take logs of key outcome vars:
gen EBR=ln(er*gdp_defl_nat78)
gen teach=ln(edu_teach_prim)
gen constr=ln(constrent_output*gdp_defl_nat78)
label var EBR "Log of extra-budgetary revenue"
label var teach "Log of teachers in primary schools"
label var constr "Log of construction output"
label var social "Social expenditure share"

*Urbanization:
gen urbanization=pop_nonagri-pop_tot
label var urbanization "Urbanization"

tsset

***Create GS work experience dummy

gen GS_work=0

***Deng Xiaoping work experience:

*Beijing
replace GS_work=1 if prov_nr==1 & year<1987
*Jiangxi
replace GS_work=1 if prov_nr==14 & year<1987
*Guangxi
replace GS_work=1 if prov_nr==20 & year<1987
*Sichuan
replace GS_work=1 if prov_nr==22 & year<1987

***Zhao Ziyang's work experience:

*Inner Mongolia
replace GS_work=1 if prov_nr==5 & year>1986 & year<1990
*Guangdong
replace GS_work=1 if prov_nr==19 & year>1986 & year<1990
*Sichuan
replace GS_work=1 if prov_nr==22 & year>1986 & year<1990

***Jiang Zemin work experience:

*Beijing
replace GS_work=1 if prov_nr==1 & year>1989 & year<2003
*Jilin
replace GS_work=1 if prov_nr==7 & year>1989 & year<2003
*Shanghai
replace GS_work=1 if prov_nr==9 & year>1989 & year<2003
*Hubei
replace GS_work=1 if prov_nr==17 & year>1989 & year<2003

***Hu Jintao work experience:

*Beijing
replace GS_work=1 if prov_nr==1 & year>2002
*Guizhou
replace GS_work=1 if prov_nr==23 & year>2002
*Gansu
replace GS_work=1 if prov_nr==27 & year>2002



****STEP 2: Generate a variable called TRANSITION that takes the value of 1 BEFORE the incumbent's term has expired in these provinces:


****PERIOD 1978-1986 DENG XIAOPING:

*Retirement/rotation RULE not created until 1982 - did not apply in 1980 when Xiaoping came to power. Thus T=0 during 1980, 1981, 1982.

***PROVINCE 1
*Previous secretary Wu De came to power 1972 - 1980 hence the first five years were 1972, 1973, 1974, 1975, 1976 and then he must have been reappointed, so the next five years were 1977, 1978, 1979, 1980, 1981
*Should have T=1 in 1981 and 1982, but since rule not created until 1982, no replacements.
***PROVINCE 20
*Secretary An Pingsheng came to power 1975, expires in 1980, so no replacements (even if the rule had applied).

***PROVINCE 14
*Secretary Jiang Weiqing came to power 1975, so no replacements (even if the rule had applied)

***PROVINCE 22
*Secretary Zhao Ziyang came to power 1975, hence no replacements  (even if the rule had applied)

***Instead of coding each province, this code accomplishes same thing around the other switches:
*All that matters for the instrument is the coding of T in the provinces where the GS worked. This code accomplishes the same thing for all provinces around the three GS switches.

sort prov_ps0 year
bys prov_ps0: gen spell_length=_n
replace spell_length=1 if spell_length==6 | spell_length==11
replace spell_length=2 if spell_length==7 | spell_length==12
replace spell_length=3 if spell_length==8 | spell_length==13
replace spell_length=4 if spell_length==9 | spell_length==14
replace spell_length=5 if spell_length==10 | spell_length==15

**zhao ziyang comes in in 1987. So take the spell-length in 1986 (and so forth)
gen spellyear_incumbent_zhao=spell_length if year==1986
sort prov_nr year
forvalues i=1(1)12{
replace spellyear_incumbent_zhao=spellyear_incumbent_zhao[_n+`i']-`i' if year ==1986-`i'
replace spellyear_incumbent_zhao=spellyear_incumbent_zhao[_n-`i']+`i' if year ==1986+`i'
}
gen T_zhao=(spellyear_incumbent_zhao<6 & year>1986 & year<1990)
*browse year prov_nr prov_ps0 spell_length spellyear_incumbent_zhao T_zhao

**Jiang zemin comes in in 1990. So take the spell-length in 1989 (and so forth)
gen spellyear_incumbent_zemin=spell_length if year==1989
forvalues i=1(1)12{
replace spellyear_incumbent_zemin=spellyear_incumbent_zemin[_n+`i']-`i' if year ==1989-`i'
replace spellyear_incumbent_zemin=spellyear_incumbent_zemin[_n-`i']+`i' if year ==1989+`i'
}
gen T_zemin=(spellyear_incumbent_zemin<6 & year>1989 & year<2003)
*browse year prov_nr prov_ps0 spell_length spellyear* T_zemin

*Hu Jintao comes in in 1990. So take the spell-length in 2002 (and so forth)
gen spellyear_incumbent_jintao=spell_length if year==2002
forvalues i=1(1)12{
replace spellyear_incumbent_jintao=spellyear_incumbent_jintao[_n+`i']-`i' if year ==2002-`i'
replace spellyear_incumbent_jintao=spellyear_incumbent_jintao[_n-`i']+`i' if year ==2002+`i'
}
gen T_jintao=(spellyear_incumbent_jintao<6 & year>2002)
*browse year prov_nr prov_ps0 spell_length spellyear* T_jintao

gen T=T_zhao+T_zemin+ T_jintao

**************

*We now have GS_work T

*Let's define our instrument:

gen instr2=(1-T)*GS_work







*******************************************
*******CLUSTERS****************************
*******************************************


*Generate variable indicating GS regimes and the province*GS regime cluster variable:

gen GS_regime=.
replace GS_regime=1 if year<1987
replace GS_regime=2 if year>1986 & year<1990
replace GS_regime=3 if year>1989 & year<2003
replace GS_regime=4 if year>2002

egen prov_GS=group(prov_nr GS_regime)

*generate province-specific time trends

gen byte time=year-1980
xi i.prov_nr*time, pre(sta)

**Create province groups

gen group_a=.
replace group_a=1 if prov_nr==21
replace group_a=1 if prov_nr==19
replace group_a=1 if prov_nr==13

replace group_a=2 if prov_nr==11
replace group_a=2 if prov_nr==9
replace group_a=2 if prov_nr==10

replace group_a=3 if prov_nr==15
replace group_a=3 if prov_nr==2
replace group_a=3 if prov_nr==1
replace group_a=3 if prov_nr==3
replace group_a=3 if prov_nr==6

replace group_a=4 if prov_nr==18
replace group_a=4 if prov_nr==17
replace group_a=4 if prov_nr==14
replace group_a=4 if prov_nr==12
replace group_a=4 if prov_nr==16

replace group_a=5 if prov_nr==20
replace group_a=5 if prov_nr==24
replace group_a=5 if prov_nr==23
replace group_a=5 if prov_nr==22.5
replace group_a=5 if prov_nr==22

replace group_a=4 if prov_nr==26
replace group_a=4 if prov_nr==4
replace group_a=4 if prov_nr==5
replace group_a=4 if prov_nr==7
replace group_a=4 if prov_nr==8

replace group_a=7 if prov_nr==30
replace group_a=7 if prov_nr==29
replace group_a=7 if prov_nr==27
replace group_a=7 if prov_nr==28

count if group_a==.
tab group_a

*generate group-specific time trends

xi i.group_a*time, pre(a_)
* a_groXtime_*

***Another clustervar: Split time into congresses and GS regimes

*82: start of period from congress
	*82, 83, 84, 85, 86
gen GS_CCP_regime=.
replace GS_CCP_regime=1 if year<1982
replace GS_CCP_regime=2 if year>1981 & year<1987
	
*87: start of GS regime and start of period from congress
	*87, 88, 89: zhao
replace GS_CCP_regime=3 if year>1986 & year<1990
	
*90: start of GS regime zemin	
	*90 91: zemin
replace GS_CCP_regime=4 if year>1989 & year<1992
	
*92: start of period from congress
	*92, 93, 94, 95, 96
replace GS_CCP_regime=5 if year>1991 & year<1997

*97: start of period from congress
	*97, 98, 99, 00, 01, 02
replace GS_CCP_regime=6 if year>1996 & year<2003
	
*2003: start of GS regime and start of period from congress	
	*2003, 2004, 2005
replace GS_CCP_regime=7 if year>2002


*NOW COMBINE THIS WITH GS_work, the variable which says whether the GS previously worked in the province or not

*bysort year: tab y2

egen GS_CCP_favored=group(GS_CCP_regime GS_work) 

rename GS_CCP_favored clustvar2

qui xi: reg local teach i.prov_nr i.year

keep time spell_length spellyear_incumbent* instr instr2 GS_work transfer_tot remittance prov_ps0 a_groXtime* staproXtime*  clustvar2 prov_nr year social teach constr EBR local age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg prev_perf0 average_dGRP0 _I* o_province0 s_low0 center_any0 s_high0 center_any0 center_high0 o_province0 o_high0 high_not_same0 no_home_experience0 no_home_high0 gdp_defl_nat78 l_livexp_urbpc l_livexp_rurpc gdpn_prim empl_primary_nr gdpn_sec gdpn_tert empl_secondary_nr empl_tertiary_nr


save "data/analysis.dta", replace
