clear
clear matrix
set more off
set scrollbufsize 500000
clear
capture log close
set more off

ssc install outreg2 , replace
ssc install ranktest , replace
ssc install xtoverid , replace
ssc install ivreg2, replace
ssc install estout, replace
adopath+ ~/Dropbox/adoplus

*cd "" 

************************************************************************************************************
*** SUMMARY STATS: TABLE 1 AND TABLE A1
************************************************************************************************************


**Table 1
*********************************************

use "data/analysis.dta", clear

**We have 180 spells, hence n=180 for these variables:
egen max_local=max(local), by(prov_ps0)
egen max_politburo0=max(politburo0), by(prov_ps0)
egen max_tenure0=max(tenure0), by(prov_ps0)
egen max_shigh0=max(s_high0), by(prov_ps0)
egen max_slow0=max(s_low0), by(prov_ps0)
egen max_ohigh0=max(o_high0), by(prov_ps0)
egen max_oprovince0=max(o_province0), by(prov_ps0)
egen max_chigh0=max(center_high0), by(prov_ps0)
egen max_cany0=max(center_any0), by(prov_ps0)
egen max_highedu0=max(higedu0), by(prov_ps0)
egen max_nohomeexp0=max(no_home_experience0), by(prov_ps0)
egen max_nohomehigh0=max(no_home_high0), by(prov_ps0)
egen max_highnotsame0=max(high_not_same0), by(prov_ps0)

egen max_home_started20=max(home_started20), by(prov_ps0)

*one obs per spell:
keep if tenure0==1

*for discussion in text about natives and locals/non-locals:
bysort max_home_started20: tab local
tab max_home_started20
tab max_local

*for the table
local background "max_local max_cany0 max_chigh0 max_oprovince0 max_ohigh0 max_highnotsame0 max_nohomeexp0 max_nohomehigh0 max_politburo0 max_home_started20 max_highedu0 max_tenure0" 

eststo clear
estpost su `background'
est store A
estpost su `background' if local==1
est store A1
estpost su `background' if local==0
est store A2

label var max_local "Local = worked both in high and low positions in prov."
label var max_cany0 "Worked in center"
label var max_chigh0 "Worked in center in high positions"
label var max_oprovince0 "Worked in other provinces"
label var max_ohigh0 "Worked in other prov. in high positions"
label var max_highnotsame0 "Worked elsewhere in high positions"
label var max_nohomeexp0 "Did not work in this province"
label var max_nohomehigh0 "Did not work in this prov. in high positions"
label var max_politburo0 "Politburo member"
label var max_home_started20 "Native province"
label var max_highedu0 "Has higher education"
label var max_tenure0 "Length of time on the job as party secretary"

*Print first panel of sumstats_local
#delimit ;
esttab A A1 A2 using "tables/backgrounds.tex", replace
		cells("mean(fmt(a2))") label booktabs nonum nogaps f noobs
		mtitle("Overall" "Local" "Not local")
		collabels(none, begin(Description) ) ;
#delimit cr 



***Table A1
*********************************************
use "data/analysis.dta", clear
set matsize 2000

***BACKGROUND
local background "local center_any0 center_high0 o_province0 o_high0  high_not_same0 no_home_experience0 no_home_high0  politburo0 home_started20 higedu0" 

eststo clear
estpost su `background'
est store A

label var local "Local = worked both in high and low positions in prov."
label var tenure0 "Length of time on the job as party secretary"

*First panel of sumstats
#delimit ;
esttab A using "tables/sumstats.tex", replace
		refcat(local60 "\textbf{Backgrounds}", nolabel) 
		cells("count(fmt(0)) mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") label booktabs nonum nogaps f noobs
		collabels("Obs" "Mean" "Std. Dev." "Min" "Max", begin(Description)) ;
#delimit cr 

***OUTCOMES

local outcomes "EBR social teach constr"

estpost su `outcomes'
est store B

#delimit ;
esttab B using "tables/sumstats.tex", append
		refcat(EBR "\textbf{Outcomes}", nolabel) 
		cells("count(fmt(0)) mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") label booktabs nonum nogaps f noobs
		collabels(none) ;
#delimit cr 

***CONTROLS

local controls "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0"
 
estpost su `controls'
est store C

label var age0 "Age"
label var tenure0 "Tenure"
label var higedu0 "Higher education"
label var home_started20 "Native province"
label var age_limit_enf0 "Retirement limit"
label var second_term_same_pos0 "Serves second term"
label var center_high0 "Worked in the center"
label var politburo0 "PS is Politburo member"
label var mrr "Marginal retention rate (MRR)"
label var pop_tot "Log population"
label var urbanization "Log urbanization"
label var GRP_lg "1yr Lagged Log GPP"
label var prev_perf0 "GPP growth of predecessor"
label var average_dGRP0 "Average GPP growth over spell until t"

#delimit ;
esttab C using "tables/sumstats.tex", append
		refcat(age0 "\textbf{Controls}", nolabel) 
		cells("count(fmt(0)) mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") label booktabs nonum nogaps f noobs
		collabels(none) ;
#delimit cr 


***OTHER VARIABLES

*net fiscal transfer
gen net_transfer=transfer_tot-remittance
gen net_trans=log(net_transfer*gdp_defl_nat78)

*gen urbrur_livexp = "urban living exp PC / rural living exp PC"
gen urbrur_livexp=l_livexp_urbpc/l_livexp_rurpc

*Generate GRP per employee in primary sector
gen GRP_pE_r=gdpn_prim/empl_primary_nr
gen GRP_pE_u=(gdpn_sec+gdpn_tert)/(empl_secondary_nr+empl_tertiary_nr)
gen GRP_pE_ur=GRP_pE_u/GRP_pE_r
sum GRP_pE_ur

*Add to sumstat.tex:
local additional "urbrur_livexp GRP_pE_ur net_trans "

estpost su `additional'
est store D

label var urbrur_livexp "Urban-rural ratio of living exp. per cap"
label var GRP_pE_ur "Urban-rural ratio of GRP per employee"
label var net_trans "Net fiscal transfer"

#delimit ;
esttab D using "tables/sumstats.tex", append
		refcat(urbrur_livexp "\textbf{Other variables}", nolabel) 
		cells("count(fmt(0)) mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") label booktabs nonum nogaps f noobs
		collabels(none) ;
#delimit cr 

*Add corruption

use "data/corruption.dta", clear
reshape long anticor_ gov_eff_, i(prov_nr) j(year)
merge m:1 year prov_nr using "data/analysis.dta"

* generate averages of corruption measures
egen av_anticorr=mean(anticor_) if anticor_!=., by(prov_nr)
egen av_gov_eff=mean(gov_eff_) if anticor_!=., by(prov_nr)
egen av_EBR=mean(EBR) if anticor_!=., by(prov_nr)
gen pop=pop_tot if year==1997
egen pop_97=mean(pop), by(prov_nr)
gen GRP_97=GRP_lg if year==1998

local corr "av_anticorr av_gov_eff"

label var av_anticorr "Provincial anti-corruption score, 1998-2003"
label var av_gov_eff "Provincial gov. efficiency score, 1998-2003"

estpost su `corr'
est store E

#delimit ;
esttab E using "tables/sumstats.tex", append
		cells("count(fmt(0)) mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") label booktabs nonum nogaps f noobs
		collabels(none) ;
#delimit cr 




************************************************************************************************************
*** Table 2: FIRST STAGE
************************************************************************************************************

use "data/analysis.dta", clear

local cont1 "_I*"
local cont2 "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 _I*"
local cont3 "politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"
local cont4 "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"

local icont=1
while "`cont`icont''"!="" {

quietly ivreg2 local instr2 a_groXtime* `cont`icont'', cluster(prov_nr clustvar2) 
eststo fs2_`icont'_cl_p
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'

*F-stat two-way clusters
quietly cluster2 local instr2 a_groXtime* `cont`icont'', fcluster(prov_nr) tcluster(clustvar2)
eststo fs_`icont'_cl_p
test instr2
estadd scalar f_excl = r(F)

*F-stat robust
quietly reg local instr2 a_groXtime* `cont`icont'', r 
eststo fs_`icont'_r_p
test instr2
estadd scalar F_excl = r(F)
 
local icont=`icont'+1
}
*
*
label var instr2 "GS Worked*Term Expires"

** Table using standard errors from ivreg2, but with F stat calculated by the cluster2 command
#delimit;
esttab fs2_1_cl_p  fs2_2_cl_p  fs2_3_cl_p  fs2_4_cl_p using "tables/firststage.tex", 
	keep(instr2 age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0)
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	replace booktabs fragment
	stats(dv N r2_a,fmt(2 0 2 ) labels("Mean, dept. var" "Number of observations" "Adj. R-Squared" ))
	mgroups("Dependent variable: PS is Local" , pattern(1 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("No" "Indiv." "Prov."  "All", begin(\emph{Controls}) nonumbers);
#delimit cr

***Add to this table the F-stat from the cluster2 model:

#delimit;
esttab fs_1_cl_p  fs_2_cl_p  fs_3_cl_p  fs_4_cl_p  using "tables/firststage.tex", 
	keep(instr2)
	star(* .1 ** .05 *** .01) se
	 wrap label varwidth(22)
	append booktabs fragment nonumbers 
	stats(f_excl,fmt(2) labels("F-stat, two-way clusters" ));
#delimit cr

***We also want to add to this table the F-stat from the robust model:

#delimit;
esttab fs_1_r_p  fs_2_r_p  fs_3_r_p  fs_4_r_p  using "tables/firststage.tex", 
	keep(instr2)
	star(* .1 ** .05 *** .01) se
	 wrap label varwidth(22)
	append booktabs fragment nonumbers 
	stats(F_excl,fmt(2) labels("F-stat, robust" ));
#delimit cr







**************************************************************************************
***Table 3: EXCLUDABILITY OF INSTRUMENT
**************************************************************************************

use "data/analysis.dta", clear

*GENERATING GS_bornstudy: PREMIER IS IN POWER AND WAS BORN IN or STUDIED IN THE PROVINCE

gen GS_bornstudy=0

****PERIOD 1978-1986 DENG XIAOPING:
*Born in Sichuan (prov_nr=22)
replace GS_bornstudy=1 if prov_nr==22 & year<1987
*Graduated from Chongqing Preparatory School, but Chongqing was a part of Sichuan at the time when Xiaoping became Premier

****PERIOD 1987-1989 ZHAO ZIYANG:
*Born in Henan (prov_nr=16)
replace GS_bornstudy=1 if prov_nr==16 & year>1986 & year<1990
*Only went to middle school

****PERIOD 1990-2002 JIANG ZEMIN
*Born in Jiangsu (prov_nr=10)
replace GS_bornstudy=1 if prov_nr==10 & year>1989 & year<2003
*Studied in Jiangsu and Shanghai (add prov_nr=9)
replace GS_bornstudy=1 if prov_nr==9 & year>1989 & year<2003

****PERIOD 2003-2005 HU JINTAO
*Born in Jiangsu (prov_nr=10)
replace GS_bornstudy=1 if prov_nr==10 & year>2002
*Studied in Beijing
replace GS_bornstudy=1 if prov_nr==1 & year>2002

label var GS_bornstudy "GS born and/or studied in province"

***MRR

local cont1 "_I*"
local cont2 "second_term_same_pos0 age0 tenure0 higedu0 home_started20 age_limit_enf0 center_high0 politburo0 pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"

local independent "GS_work instr2"

eststo clear

foreach indepvar in `independent' {

local icont=1
while "`cont`icont''"!="" {

qui cluster2 mrr GS_bornstudy `indepvar' `cont`icont''   if year<1993, fcluster(prov_nr) tcluster(clustvar2)
eststo mrr_`icont'_`indepvar'

local icont=`icont'+1
}
}
***Politburo

local cont1 "_I*"
local cont2 "second_term_same_pos0 age0 tenure0 higedu0 home_started20 age_limit_enf0 center_high0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"

local independent "GS_work instr2"

foreach indepvar in `independent' {

local icont=1
while "`cont`icont''"!="" {

qui cluster2 politburo0 GS_bornstudy `indepvar' `cont`icont''  , fcluster(prov_nr) tcluster(clustvar2) 
eststo pb_`icont'_`indepvar'

local icont=`icont'+1
}
}
estimates dir
*

***Fiscal transfers**

sum transfer_tot remittance
gen net_transfer=transfer_tot-remittance
gen net_trans=log(net_transfer*gdp_defl_nat78)
label var net_trans "Net fiscal transfer"

*REGRESSIONS

local cont1 "_I*"
local cont2 "second_term_same_pos0 age0 tenure0 higedu0 home_started20 age_limit_enf0 center_high0 politburo0 pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"

local dependent "net_trans "
local independent "GS_work instr2"

foreach depvar in `dependent' {

foreach indepvar in `independent' {

local icont=1
while "`cont`icont''"!="" {

quietly cluster2 `depvar' GS_bornstudy `indepvar' `cont`icont''  , fcluster(prov_nr) tcluster(clustvar2)
eststo fiscal_`icont'_`indepvar'

local icont=`icont'+1
}
}
}

estimates dir

**Printing the reg table
*PANEL A
#delimit;
esttab mrr_1_GS_work mrr_2_GS_work fiscal_1_GS_work fiscal_2_GS_work pb_1_GS_work pb_2_GS_work using "tables/reality_check.tex", 
	keep(GS_bornstudy GS_work politburo0) booktabs
	cells(b(star fmt(3)) se(par fmt(3))) 
	stats(N r2_a,fmt(0 2) labels("Number of observations" "Adj. R-Squared" )) 
	star(* .1 ** .05 *** .01) fragment
	collabels(,none) 
	replace
	mgroups("\specialcell{Fiscal MRR\\(before fiscal reform)}" "\specialcell{Net fiscal transfer\\(after fiscal reform)}" "\specialcell{PS Politburo Member\\(all years)}", pattern(1 0 1 0 1 0) begin(\emph{Dependent variable:})	
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
	mlabel("(1)" "(2)" "(3)" "(4)" "(5)" "(6)",nonumbers) nonumbers
	coeflabels(instr2 "GS Worked*Term Expires" GS_bornstudy "GS was born and/or studied in the province"  GS_work "GS worked in the province"  local60 "PS is local" tenure0 "Tenure" home_started0 "Native province" center_high0 "Worked in the center" politburo0 "PS is Politburo member" mrr "MRR" prev_perf0 "GPP growth of predecessor" average_dGRP0 "Average GPP growth")
	nogaps
	nolegend;
#delimit cr

*PANEL B
#delimit;
esttab mrr_1_instr2 mrr_2_instr2 fiscal_1_instr2 fiscal_2_instr2 pb_1_instr2 pb_2_instr2   using "tables/reality_check.tex", 
	keep(GS_bornstudy  instr2 politburo0) booktabs
	cells(b(star fmt(3)) se(par fmt(3))) 
	stats(N r2_a,fmt(0 2) labels("Number of observations" "Adj. R-Squared" )) 
	star(* .1 ** .05 *** .01) fragment
	collabels(,none) 
	append
	mgroups("\specialcell{Fiscal MRR\\(before fiscal reform)}" "\specialcell{Net fiscal transfer\\(after fiscal reform)}" "\specialcell{PS Politburo Member\\(all years)}", pattern(1 0 1 0 1 0) begin(\emph{Dependent variable:})	
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
	mlabel("(1)" "(2)" "(3)" "(4)" "(5)" "(6)",nonumbers) nonumbers
	coeflabels(instr2 "GS Worked*Term Expires" GS_bornstudy "GS was born and/or studied in the province" GS_work "GS worked in the province"  local60 "PS is local" tenure0 "Tenure" home_started0 "Native province" center_high0 "Worked in the center" politburo0 "PS is Politburo member" mrr "MRR" prev_perf0 "GPP growth of predecessor" average_dGRP0 "Average GPP growth")
	nogaps
	nolegend;
#delimit cr







****************************************************************
***Table 4: The impact of local on provincial governance
****************************************************************

use "data/analysis.dta", clear

estimates clear
eststo clear

global controls "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"
global Controls "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 i.prov_nr i.year"

local dependent "EBR social teach constr"
foreach depvar in `dependent' {
*OLS reg:
quietly ivreg2 `depvar' local a_groXtime* $controls , cluster(prov_nr clustvar2)
eststo ols_`depvar'
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'
estadd local Controls "All"
*IV reg:
quietly ivreg2 `depvar'  $controls a_groXtime* (local=instr2)  , cluster(prov_nr clustvar2)   
eststo iv_`depvar'
estadd scalar f_KP = e(widstat)
estadd local Controls "All"
**Within r squared for OLS
quietly xi: xtreg `depvar' local a_groXtime*  $Controls , fe vce(cl prov_nr)
eststo olsR2_`depvar'
*Reduced form
quietly ivreg2 `depvar' instr2 a_groXtime* $controls, cluster(prov_nr clustvar2)
eststo rf_`depvar'
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'
estadd local Controls "All"
**Within r squared for RF
quietly xi: xtreg `depvar' instr2 a_groXtime*  $Controls , fe vce(cl prov_nr)
eststo rfR2_`depvar'
local icont=`icont'+1
}


estimates dir

** Print table
************************************************************************************

*Table with first stage, ols, iv:

label var instr2 "GS Worked*Term Expires"

#delimit;
esttab ols_social ols_teach ols_constr ols_EBR using "tables/baseline.tex", 
	keep(local tenure0 home_started20 politburo0) 
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	replace booktabs fragment nonumbers
	scalars("Controls")
	mgroups("Panel A: OLS ", pattern(1 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("Social" "Teachers" "Construction"  "EBR",nonumbers);
#delimit cr
*Add the within Rsquared
#delimit;
esttab olsR2_social olsR2_teach olsR2_constr olsR2_EBR  using "tables/baseline.tex", 
	keep(local)
	star(* .1 ** .05 *** .01) se
	 wrap label varwidth(22)
	append booktabs fragment
	stats(r2_w,fmt(2) labels("Within R-squared" ));
#delimit cr
*IV table
#delimit;
esttab iv_social iv_teach iv_constr iv_EBR using "tables/baseline.tex", 
	keep(local tenure0 home_started20 politburo0) 
	star(* .1 ** .05 *** .01) se
	 wrap label varwidth(22)
	scalars("Controls")
	append booktabs fragment nonumbers
	mgroups("Panel B: IV ", pattern(1 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("Social" "Teachers" "Construction"  "EBR",nonumbers);
#delimit cr
*RF table
#delimit;
esttab rf_social rf_teach rf_constr rf_EBR using "tables/baseline.tex", 
	keep(instr2 tenure0 home_started20 politburo0) 
	star(* .1 ** .05 *** .01) se
	 wrap label varwidth(22)
	scalars("Controls")
	append booktabs fragment nonumbers
	stats( dv N  ,fmt(2 0) label("Mean, dept. var" "Number of observations" )) 
	mgroups("Panel C: Reduced form ", pattern(1 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("Social" "Teachers" "Construction"  "EBR",nonumbers);
#delimit cr
*Add the within Rsquared
#delimit;
esttab rfR2_social rfR2_teach rfR2_constr rfR2_EBR  using "tables/baseline.tex", 
	keep(instr2)
	star(* .1 ** .05 *** .01) se
	 wrap label varwidth(22)
	append booktabs fragment
	stats(r2_w,fmt(2) labels("Within R-squared" ));
#delimit cr






****************************************************************
***Table 5: Promotion mechanism
****************************************************************

use "data/promotiondata.dta", clear
label var CumAv_Soc_Tenu "Social (Avg.)" 
label var CumAv_Teach_TenuPC "Teachers Per Capita (Avg.)"
label var CumAv_Constr_Tenu "Construction (Avg.)"
label var CumAv_EBF_Tenu "EBR (Avg.)"
label var local "PS is Local"
label var future "Promotion"
label var average_dGRP "Average GPP Growth"

local independent "CumAv_Soc_Tenu CumAv_Teach_TenuPC CumAv_Constr_Tenu CumAv_EBF_Tenu local"

eststo clear

foreach indepvar in `independent' {
local cont1 "age age_limit_enf higedu tenure center_high GRP_pC_lg politburo second_term_same_pos  prev_perf"
local cont2 "age age_limit_enf higedu tenure center_high GRP_pC_lg politburo second_term_same_pos  prev_perf average_dGRP "

local icont=1
while "`cont`icont''"!="" {

qui xi: probit future `cont`icont'' `indepvar'  i.year i.prov_nr, vce(cl prov_nr)
qui margins, dydx(*) post
eststo
local icont=`icont'+1

}
}
*

**Printing Panel A (without controls for growth)
#delimit;
esttab est1 est3 est5 est7 est9 using "tables/promotion.tex", 
	keep(CumAv_Soc_Tenu CumAv_Teach_TenuPC CumAv_Constr_Tenu CumAv_EBF_Tenu local) 
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	replace booktabs fragment numbers
	mgroups("Panel A: no controls for growth performance", pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ;
#delimit cr
*IV table
#delimit;
esttab est2 est4 est6 est8 est10 using "tables/promotion.tex", 
	keep(CumAv_Soc_Tenu CumAv_Teach_TenuPC CumAv_Constr_Tenu CumAv_EBF_Tenu local average_dGRP) 
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	append booktabs fragment numbers
	mgroups("Panel B: Controls for growth performance ", pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}));
#delimit cr



***Table 5 part two (in Appendix): Promotion mechanism, with interaction with local
****************************************************************

local independent2 "CumAv_Soc_Tenu CumAv_Teach_TenuPC CumAv_Constr_Tenu CumAv_EBF_Tenu"

foreach measure in `independent2' {
gen l_`measure'=local*`measure'
}
*

label var l_CumAv_Soc_Tenu "Social (Avg.)*Local" 
label var l_CumAv_Teach_Tenu "Teachers (Avg.)*Local"
label var l_CumAv_Teach_TenuPC "Teachers Per Capita (Avg.)*Local"
label var l_CumAv_Constr_Tenu "Construction (Avg.)*Local"
label var l_CumAv_EBF_Tenu "EBR (Avg.)*Local"

eststo clear

local cont1 "age age_limit_enf higedu tenure center_high GRP_pC_lg politburo second_term_same_pos  prev_perf"
local cont2 "age age_limit_enf higedu tenure center_high GRP_pC_lg politburo second_term_same_pos  prev_perf average_dGRP "

local icont=1
while "`cont`icont''"!="" {

*social with interaction
qui xi: probit future CumAv_Soc_Tenu l_CumAv_Soc_Tenu local `cont`icont'' i.year i.prov_nr, vce(cl prov_nr)
qui margins, dydx(*) post
eststo

*teach with interaction
qui xi: probit future  CumAv_Teach_TenuPC l_CumAv_Teach_TenuPC local `cont`icont'' i.year i.prov_nr, vce(cl prov_nr)
qui margins, dydx(*) post
eststo

*construction with interaction
qui xi: probit future  CumAv_Constr_Tenu l_CumAv_Constr_Tenu local `cont`icont'' i.year i.prov_nr, vce(cl prov_nr)
qui margins, dydx(*) post
eststo

*ebf with interaction
qui xi: probit future CumAv_EBF_Tenu l_CumAv_EBF_Tenu local `cont`icont'' i.year i.prov_nr, vce(cl prov_nr)
qui margins, dydx(*) post
eststo

local icont=`icont'+1

}
*

**Printing Panel A (without controls for growth)
#delimit;
esttab est1 est2 est3 est4 using "tables/promotion_i.tex", 
	keep(l_CumAv_Soc_Tenu l_CumAv_Teach_TenuPC l_CumAv_Constr_Tenu l_CumAv_EBF_Tenu CumAv_Soc_Tenu CumAv_Teach_TenuPC CumAv_Constr_Tenu CumAv_EBF_Tenu local) 
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	replace booktabs fragment numbers
	mgroups("Panel A: no controls for growth performance", pattern(1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ;
#delimit cr
*IV table
#delimit;
esttab est5 est6 est7 est8 using "tables/promotion_i.tex", 
	keep(l_CumAv_Soc_Tenu l_CumAv_Teach_TenuPC l_CumAv_Constr_Tenu l_CumAv_EBF_Tenu CumAv_Soc_Tenu CumAv_Teach_TenuPC CumAv_Constr_Tenu CumAv_EBF_Tenu local average_dGRP) 
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	append booktabs fragment numbers
	mgroups("Panel B: Controls for growth performance ", pattern(1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}));
#delimit cr








**************************************************************************************
*** TABLE 6: INTERACTIONS WITH INEQUALITY
**************************************************************************************

use "data/analysis.dta", clear

*Generate urbrur_livexp = "urban living exp PC / rural living exp PC"
gen urbrur_livexp=l_livexp_urbpc/l_livexp_rurpc

gen ln_urbrur_livexp=ln(urbrur_livexp)

*Generate GRP per employee in primary sector
gen GRP_pE_r=gdpn_prim/empl_primary_nr
gen GRP_pE_u=(gdpn_sec+gdpn_tert)/(empl_secondary_nr+empl_tertiary_nr)
gen GRP_pE_ur=GRP_pE_u/GRP_pE_r

gen ln_GRP_pE_ur=ln(GRP_pE_ur)

*Generate interactions
destring   urbrur* GRP_pE_ur ln_*, replace
local inequality "  urbrur_livexp GRP_pE_ur"
foreach measure in `inequality' {
gen local_`measure'=local*`measure'
gen instr2_`measure'=instr2*`measure'
}
*
eststo clear

global c4 "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"

*interaction with each measure
local inequality "urbrur_livexp GRP_pE_ur"
foreach x in `inequality' {
*OLS reg on outcome teachers
quietly ivreg2 teach local `x' local_`x' $c4 a_groXtime*, cluster(prov_nr clustvar2)
eststo t_`x'_time
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'
estadd local Controls "All"

*OLS reg on outcome social
quietly ivreg2 social local `x' local_`x' $c4 a_groXtime*, cluster(prov_nr clustvar2)
eststo s_`x'_time
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'
estadd local Controls "All"

*OLS reg on outcome EBR
quietly ivreg2 EBR local `x' local_`x' $c4 a_groXtime*, cluster(prov_nr clustvar2)
eststo e_`x'_time
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'
estadd local Controls "All"

}
*

*Print main table for paper with economic region trends

label var local_urbrur_livexp "Local*(UR ratio of living expenditure per Capita)"
label var urbrur_livexp "Urban-rural ratio of living expenditure per Capita"
label var local_GRP_pE_ur "Local*(UR ratio of GRP per employee)"
label var GRP_pE_ur "Urban-rural ratio of GRP per employee"

#delimit;
esttab   s_urbrur_livexp_time  t_urbrur_livexp_time s_GRP_pE_ur_time t_GRP_pE_ur_time using "tables/inequality.tex",
	keep(local  urbrur_livexp local_urbrur_livexp GRP_pE_ur local_GRP_pE_ur  )
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	replace booktabs fragment nonumbers
	scalars("Controls")
	stats(dv N ,fmt(2 0 ) labels("Mean, dept. var" "Number of observations"  ))
	mgroups("Panel A: OLS" , pattern( 1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("Social" "Teachers"  "Social" "Teachers" , begin(\emph{Outcome}) nonumbers);
#delimit cr

*IV results: interaction with each measure
local inequality "  urbrur_livexp GRP_pE_ur "
foreach x in `inequality' {
*IV reg on outcome teachers
quietly ivreg2 teach  `x'  $c4 a_groXtime* (local local_`x' = instr2 instr2_`x'), cluster(prov_nr clustvar2)
eststo t_`x'_time_iv
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'
estadd local Controls "All"

*IV reg on outcome social
quietly ivreg2 social `x' $c4 a_groXtime* (local local_`x' = instr2 instr2_`x'), cluster(prov_nr clustvar2)
eststo s_`x'_time_iv
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'
estadd local Controls "All"

*IV reg on outcome EBR
quietly ivreg2 EBR `x' $c4 a_groXtime* (local local_`x' = instr2 instr2_`x'), cluster(prov_nr clustvar2)
eststo e_`x'_time_iv
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'
estadd local Controls "All"

}
*

*Print IV table

#delimit;
esttab  s_urbrur_livexp_time_iv  t_urbrur_livexp_time_iv s_GRP_pE_ur_time_iv t_GRP_pE_ur_time_iv  using "tables/inequality.tex",
	keep(local urbrur_livexp local_urbrur_livexp  GRP_pE_ur local_GRP_pE_ur  )
	order(local urbrur_livexp local_urbrur_livexp  GRP_pE_ur local_GRP_pE_ur )
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	scalars("Controls")
	append booktabs fragment nonumbers
	stats(dv N ,fmt(2 0) labels("Mean, dept. var" "Number of observations"  ))
	mgroups("Panel B: IV" , pattern( 1 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel( "Social" "Teachers" "Social" "Teachers" , begin(\emph{Outcome}) nonumbers);
#delimit cr




************************************************************************************************************
*** CORRUPTION AND EBR: FIGURE A2 AND TABLE A2
************************************************************************************************************

use "data/corruption.dta", clear
reshape long anticor_ gov_eff_, i(prov_nr) j(year)
merge m:1 year prov_nr using "data/analysis.dta"
***!!!*** switch

// generate averages of corruption measures
egen av_anticorr=mean(anticor_) if anticor_!=., by(prov_nr)
egen av_gov_eff=mean(gov_eff_) if anticor_!=., by(prov_nr)
egen av_ebf=mean(EBR) if anticor_!=., by(prov_nr)
gen pop=pop_tot if year==1997
egen pop_97=mean(pop), by(prov_nr)
gen GRP_97=GRP_lg if year==1998

// generate geo-region, as in the paper with corruptino data 2= central; 3 - western
gen geo_region=1
replace geo_region=2 if prov_nr==4|prov_nr==7|prov_nr==12|prov_nr==14|prov_nr==16|prov_nr==17|prov_nr==18
replace geo_region=3 if prov_nr==20|prov_nr==22.5|prov_nr==22|prov_nr==23|prov_nr==24|prov_nr==25|prov_nr==27|prov_nr==28|prov_nr==29|prov_nr==30

gen eastern=1 
replace eastern=0 if geo_region==2 |geo_region==3

// labels
label var av_ebf "EBR, 1998-2003" 
label var av_anticorr "Anti-corruption score, 1998-2003"
label var av_gov_eff "Gov. efficiency score, 1998-2003"
label var pop_97 "Log population, 1997" 
label var GRP_97 "Log GPP, 1997"
label var eastern "Eastern province dummy"

eststo clear
// in x-section ebf is negotively significantlyu correlated with anti-corruption efforts or government efficiency !!!! 
// conditional on population and initial (1997) gdp level. The corruption data average 1998-2003

reg av_ebf av_anticorr pop_tot GRP_lg if year==1998, r
avplot av_anticorr
eststo A

reg av_ebf av_anticorr pop_tot GRP_lg eastern if year==1998, r
*avplot av_anticorr
eststo B

reg av_ebf av_gov_eff pop_tot GRP_lg if year==1998 , r
avplot av_gov_eff
eststo C

reg av_ebf av_gov_eff pop_tot GRP_lg eastern if year==1998, r
*avplot av_anticorr
eststo D

reg av_ebf av_anticorr av_gov_eff  pop_tot GRP_lg if year==1998 , r
reg av_ebf av_anticorr av_gov_eff  pop_tot GRP_lg eastern  if year==1998 , r
eststo E

****Table
#delimit;
esttab A B C D E using "tables/corruption.tex",
	keep(av_anticorr av_gov_eff  pop_tot GRP_lg eastern ) 
	star(* .1 ** .05 *** .01) se
	brackets wrap label varwidth(22)
	replace booktabs fragment
	stats(N r2_a , labels("Number of observations" "Adj. R-Squared" ));
#delimit cr

 


**************************************************************************************
*** FIGURE A3: SIX ECONOMIC REGIONS
**************************************************************************************


use "data/ruralconsinc.dta", clear

*income table:
#delimit;
graph twoway 
(line ruralincPC Year  if reg_nr==1, lwidth(0.8) lcolor(blue))
(line ruralincPC Year  if reg_nr==2, lwidth(0.8) lcolor(red))
(line ruralincPC Year  if reg_nr==3, lwidth(0.8) lcolor(green))
(line ruralincPC Year  if reg_nr==4, lwidth(0.8) lcolor(orange))
(line ruralincPC Year  if reg_nr==5, lwidth(0.8) lcolor(gray))
(line ruralincPC Year  if reg_nr==7, lwidth(0.8) lcolor(purple)), 
graphregion(fcolor(white))
legend(off)
title(Real Per Capita Rural Income)
;
#delimit cr
graph export "figures/regional_income_caption.eps", replace

*consumption table:
#delimit;
graph twoway 
(line ruralconsPC Year  if reg_nr==1, lwidth(0.8) lcolor(blue))
(line ruralconsPC Year  if reg_nr==2, lwidth(0.8) lcolor(red))
(line ruralconsPC Year  if reg_nr==3, lwidth(0.8) lcolor(green))
(line ruralconsPC Year  if reg_nr==4, lwidth(0.8) lcolor(orange))
(line ruralconsPC Year  if reg_nr==5, lwidth(0.8) lcolor(gray))
(line ruralconsPC Year  if reg_nr==7, lwidth(0.8) lcolor(purple)), 
graphregion(fcolor(white))
legend(
pos(11) ring(0) col(1)
label(1 "East Coast") label(2 "South Coast")
label(3 "North Coast") label(4 "Central Core") 
label(5 "Hinterland")
 label(6 "Far West"))
title(Real Per Capita Rural Consumption)
;
#delimit cr
graph export "figures/regional_consumption_caption.eps", replace


**MAP

use "data/division_of_provinces_into_regions.dta", clear

ssc install spmap
ssc install shp2dta
ssc install mif2dta 

*create two datasets, chinamap and coord:
shp2dta using "data/CHN_adm1", database("data/chinamap") coordinates("data/coord") genid(id) replace

use "data/chinamap", clear

gen group_a=.

replace group_a = 4 in 1
replace group_a = 5 in 2
replace group_a = 3 in 3
replace group_a = 7 in 4
replace group_a = 1 in 5
replace group_a = 7 in 6
replace group_a = 3 in 7
replace group_a = 3 in 8
replace group_a = 7 in 9
replace group_a = 5 in 10
replace group_a = 2 in 11
replace group_a = 4 in 12
replace group_a = 4 in 13
replace group_a = 4 in 14
replace group_a = 6 in 15
replace group_a = 4 in 16
replace group_a = 2 in 17
replace group_a = 5 in 18
replace group_a = 2 in 19
replace group_a = 1 in 20
replace group_a = 1 in 22
replace group_a = 2 in 23
replace group_a = 5 in 24
replace group_a = 6 in 25
replace group_a = 2 in 26
replace group_a = 5 in 27
replace group_a = 3 in 27
replace group_a = 5 in 28
replace group_a = 1 in 29
replace group_a = 3 in 31
replace group_a = 6 in 32

keep if group_a!=.

replace group_a = 3 if group_a == 2

spmap group_a using "data/coord", id(id) cln(8) fcolor(purple gray orange green blue red) legend( size(large) order(6 7 5 4 3 2) label(6 "1. East Coast") label(7 "2. South Coast") label(5 "3. North Coast") label(4 "4. Central Core")    label(3 "5. Hinterland")  label(2 "6. Far West")   color(gs6)) 
graph export "figures/map.eps", replace





**************************************************************************************
*** FIGURE A4 and TABLE A5: EVENT STUDY FIGURES and regressions checking pre-trends
**************************************************************************************

use "data/analysis.dta", clear

**Timeline stuff
gen timeline_zhao=spellyear_incumbent_zhao-5 if spellyear_incumbent_zhao>1 & spellyear_incumbent_zhao<11
*Timeline 2 defined when the GS is in office
gen timeline_zhao2=timeline_zhao if year>1986 & year<1990

gen timeline_zemin=spellyear_incumbent_zemin-5 if spellyear_incumbent_zemin>1 & spellyear_incumbent_zemin<11
gen timeline_zemin2=timeline_zemin if year>1989 & year<2002

gen timeline_jintao=spellyear_incumbent_jintao-5 if spellyear_incumbent_jintao>1 & spellyear_incumbent_jintao<11
gen timeline_jintao2=timeline_jintao if year>2002

*Create timeline

*1: Obs when current GS serves around each switch (i.e., starting when T is defined and the province-year obs after the transition period)
gen timeline1=timeline_zhao2
replace timeline1=timeline_zemin2 if timeline_zemin2!=.
replace timeline1=timeline_jintao2 if timeline_jintao2!=.

**********GENERATE INDICATOR VARS FOR EACH POINT ON TIMELINE, and interactions with GS worked

*sum timeline1
*range from -3 to 5, including zero. 1 is the first year of the new guy

forvalues j=-3(1)5{
local t=`j'+4
gen D`t'_tl1=(timeline1==`j')
gen D`t'_tl1_GS=D`t'_tl1*GS_work
}


**********DRAW GRAPHS

gen t = _n

rename social Social
rename teach Teachers
rename constr Construction

global controls "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"
global Controls "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 i.prov_nr i.year"

***Omit D3:

global Ttimeline1 "D1_tl1 D2_tl1 D4_tl1 D5_tl1 D6_tl1 D7_tl1 D8_tl1 D9_tl1"
global Ttimeline1_GS "D1_tl1_GS D2_tl1_GS D4_tl1_GS D5_tl1_GS D6_tl1_GS D7_tl1_GS D8_tl1_GS D9_tl1_GS" 
global Ttimeline2 "D1_tl2 D2_tl2 D4_tl2 D5_tl2 D6_tl2 D7_tl2 D8_tl2 D9_tl2"
global Ttimeline2_GS "D1_tl2_GS D2_tl2_GS D4_tl2_GS D5_tl2_GS D6_tl2_GS D7_tl2_GS D8_tl2_GS D9_tl2_GS" 
global Ttimeline3 "D1_tl3 D2_tl3 D4_tl3 D5_tl3 D6_tl3 D7_tl3 D8_tl3 D9_tl3"
global Ttimeline3_GS "D1_tl3_GS D2_tl3_GS D4_tl3_GS D5_tl3_GS D6_tl3_GS D7_tl3_GS D8_tl3_GS D9_tl3_GS" 

*Drawing graphs:
foreach out in Social Teachers Construction EBR {
quietly ivreg2 `out' $Ttimeline1_GS $Ttimeline1 GS_work $controls a_groXtime* if timeline1!=., cluster(prov_nr)

gen coef =.
gen low =.
gen high =.

forval k=1/2 {
replace coef = _b[D`k'_tl1_GS] if time==`k'
replace low = _b[D`k'_tl1_GS]-1.96*_se[D`k'_tl1_GS] if time==`k'
replace high = _b[D`k'_tl1_GS]+1.96*_se[D`k'_tl1_GS] if time==`k'
}

forval k=4/9 {
replace coef = _b[D`k'_tl1_GS] if time==`k'
replace low = _b[D`k'_tl1_GS]-1.96*_se[D`k'_tl1_GS] if time==`k'
replace high = _b[D`k'_tl1_GS]+1.96*_se[D`k'_tl1_GS] if time==`k'
}

replace coef = 0 if time==3
replace low = 0 if time==3
replace high = 0 if time==3

preserve
collapse (mean) coef high low, by(time)
keep if time<=9
keep if time>1

label def ti  2 "-3" 3 "-2" 4 "-1" 5 "1" 6 "2" 7 "3" 8 "4" 9 "5" 
label values t ti

twoway (scatter coef t, connect(l) lwidth(medthick) lcolor(blue) mcolor(blue) msize(medium) ) (line high t, lpattern(dash) lcolor(gray) lwidth(medthin)) (line low t, lpattern(dash) lcolor(gray) lwidth(medthin)), title(`out') xline(5, lcolor(red) lwidth(medthick)) yline(0, lcolor(black) lwidth(medthin)) xlabel( 2 3 4 5 6 7 8 9, valuelabel) xtitle(Years relative to expiration of incumbent's term) ytitle(Coefficient) legend(off)  graphregion(fcolor(white))
graph save "figures/graph_`out'", replace 
restore

drop coef high low
}

graph combine  "figures/graph_Social" "figures/graph_Teachers" "figures/graph_Construction" "figures/graph_EBR"
graph export "figures/pretrends.png", replace



**************************************************************************************
*** TABLE A4: COMPLIER CHARACTERISTICS
**************************************************************************************

use "data/analysis.dta", clear

reg local instr2
*0.1888

tab higedu0
*Pr(=1)=0.6428
reg local instr2 if higedu0==1 
*First stage for college graduates: .1635071
*So by formula 4.4.8, we get .1635071/0.1888=0.87, where 0.1888 comes from the overall first stage above.

tab age_limit_enf0 
reg local instr2 if age_limit_enf0==1 
*First stage:   .0405522 
*So by formula 4.4.8, we get .0405522 /.1888=0.22

tab center_high0 
reg local instr2 if center_high0==1 
*First stage:   .0465368
*So by formula 4.4.8, we get .0465368/.1888=0.25

tab politburo0
reg local instr2 if politburo0==1 
*First stage:    .0415385
*So by formula 4.4.8, we get  .0415385/.1888=0.22




****************************************************************
***Table A5: The impact of local on provincial governance, using clusters at the province level
****************************************************************

use "data/analysis.dta", clear

estimates clear
eststo clear

global controls "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"
global Controls "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 i.prov_nr i.year"

*First stage:
ivreg2 local instr2 a_groXtime* $controls, cluster(prov_nr) 

local dependent " social teach constr EBR"
foreach depvar in `dependent' {
*OLS reg:
ivreg2 `depvar' local a_groXtime* $controls , cluster(prov_nr)

*IV reg:
ivreg2 `depvar'  $controls a_groXtime* (local=instr2)  , cluster(prov_nr)   

*Reduced form
ivreg2 `depvar' instr2 a_groXtime* $controls, cluster(prov_nr)

}
*


**************************************************************************************
*** TABLE A6: FIRST STAGE AND BASELINE CONTROLLING FOR PROVINCE-SPECIFIC TIME TRENDS
**************************************************************************************


use "data/analysis.dta", clear
eststo clear

global controls "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"
global Controls "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 i.prov_nr i.year"

quietly ivreg2 local  instr2 staproXtime* $controls , cluster(prov_nr clustvar2) 
eststo fs2_cl
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'

*F-stat two-way clusters
quietly cluster2 local instr2 staproXtime* $controls, fcluster(prov_nr) tcluster(clustvar2)
eststo fs_cl
test  instr2
estadd scalar f_excl = r(F)

*F-stat robust
qui reg local instr2 staproXtime* $controls , r 
eststo fs_r
test  instr2
estadd scalar F_excl = r(F)
 
*
*
label var instr2 "GS Worked*Term Expires"

** Table using standard errors from ivreg2, but with F stat calculated by the cluster2 command
#delimit;
esttab fs2_cl fs_cl fs_r fs_r using "tables/baseline_provcont.tex", 
	keep(instr2)
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	replace booktabs fragment
	stats(dv N r2_a f_excl F_excl,fmt(2 0 2 2 2) labels("Mean, dept. var" "Number of observations" "Adj. R-Squared" "F-stat, 2w" "F-stat, r" ))
	mgroups("First Stage" , begin(\textbf{Pre-trends}) pattern(1 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("\specialcell{Dependent variable:\\PS is Local}" "\specialcell{F-stat:\\two-way clustering}"  "\specialcell{F-stat:\\robust}" "\specialcell{Adj. R-Squared}" , nonumbers);
#delimit cr

**Baseline

estimates clear
eststo clear

local dependent "EBR social teach constr" 

foreach depvar in `dependent' {
*OLS reg:
quietly ivreg2 `depvar' local staproXtime* $controls , cluster(prov_nr clustvar2)
eststo ols_`depvar'
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'
*estadd local Controls "All"
*IV reg:
quietly ivreg2 `depvar'  $controls staproXtime* (local= instr2)  , cluster(prov_nr clustvar2)   
eststo iv_`depvar'
*estadd local Controls "All"
**Within r squared for OLS
quietly xi: xtreg `depvar' local staproXtime*  $Controls , fe vce(cl prov_nr)
eststo olsR2_`depvar'
*Reduced form
quietly ivreg2 `depvar'  instr2 staproXtime* $controls, cluster(prov_nr clustvar2)
eststo rf_`depvar'
qui sum `e(depvar)' if e(sample)==1 
estadd scalar dv=`r(mean)'
estadd local Controls "All"
**Within r squared for RF
quietly xi: xtreg `depvar'  instr2 staproXtime*  $Controls , fe vce(cl prov_nr)
eststo rfR2_`depvar'
local icont=`icont'+1

}


estimates dir

*Table

label var  instr2 "GS Worked*Term Expires"

#delimit;
esttab ols_social ols_teach ols_constr ols_EBR using "tables/baseline_provcont.tex", 
	keep(local) 
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	append booktabs fragment nonumbers
	mgroups("Panel A: OLS ", pattern(1 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("Social" "Teachers" "Construction"  "EBR",nonumbers);
#delimit cr
*Add the within Rsquared
#delimit;
esttab olsR2_social olsR2_teach olsR2_constr olsR2_EBR  using "tables/baseline_provcont.tex", 
	keep(local)
	star(* .1 ** .05 *** .01) se
	 wrap label varwidth(22)
	append booktabs fragment
	stats(r2_w,fmt(2) labels("Within R-squared" ));
#delimit cr
*IV table
#delimit;
esttab iv_social iv_teach iv_constr iv_EBR using "tables/baseline_provcont.tex", 
	keep(local) 
	star(* .1 ** .05 *** .01) se
	 wrap label varwidth(22)
	append booktabs fragment nonumbers
	mgroups("Panel B: IV ", pattern(1 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("Social" "Teachers" "Construction"  "EBR",nonumbers);
#delimit cr
*RF table
#delimit;
esttab rf_social rf_teach rf_constr rf_EBR using "tables/baseline_provcont.tex", 
	keep(instr2) 
	star(* .1 ** .05 *** .01) se
	 wrap label varwidth(22)
	scalars("Controls")
	append booktabs fragment nonumbers
	stats( dv N  ,fmt(2 0) label("Mean, dept. var" "Number of observations" )) 
	mgroups("Panel C: Reduced form ", pattern(1 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("Social" "Teachers" "Construction"  "EBR",nonumbers);
#delimit cr
*Add the within Rsquared
#delimit;
esttab rfR2_social rfR2_teach rfR2_constr rfR2_EBR  using "tables/baseline_provcont.tex", 
	keep(instr2)
	star(* .1 ** .05 *** .01) se
	 wrap label varwidth(22)
	append booktabs fragment
	stats(r2_w,fmt(2) labels("Within R-squared" ));
#delimit cr






****************************************************************
***Table A7: Interaction with tenure
****************************************************************

use "data/analysis.dta", clear

local cont1 "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 _I*"
local cont2 "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"

*for within r squared:
local Cont1 "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 i.year i.prov_nr"
local Cont2 "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 i.year i.prov_nr"

local dependent "social teach constr EBR"

eststo clear

foreach depvar in `dependent' {

local icont=1
while "`cont`icont''"!="" {

*** OLS Cluster
qui reg `depvar' local tenure0 `cont`icont'', r
egen average_tenure0=mean(tenure0) if e(sample)==1
gen tenurediff=tenure0-average_tenure0
gen interaction=local*tenurediff
gen interaction_instr2=instr2*tenurediff

qui ivreg2 `depvar' local interaction `cont`icont'' a_groXtime*, cluster(prov_nr clustvar2)
eststo ols_`icont'_`depvar'
estadd local Controls "All"

*within r squared
quietly xi: xtreg `depvar' local interaction `Cont`icont'' a_groXtime*, fe vce(cl prov_nr)
eststo olsR2_`icont'_`depvar'

*** IV Cluster
quietly ivreg2 `depvar' `cont`icont'' a_groXtime* (local interaction = instr2 interaction_instr2), cl(prov_nr clustvar2)
eststo  iv_`icont'_`depvar'
estadd local Controls "All"

drop average_tenure0 tenurediff interaction interaction_`instrvar'

local icont=`icont'+1
}
}
*
estimates dir

***Generating the table: panel a ols
#delimit;
esttab ols_2_social ols_2_teach ols_2_constr ols_2_EBR using "tables/tenure.tex", 
	keep(local interaction tenure0)
	stats(N ,fmt(0 ) labels("Number of observations" )) 
	star(* .1 ** .05 *** .01) se 
	scalars("Controls")
	wrap fragment booktabs 
	coeflabels(local "PS is local" tenure0 "Tenure" interaction "PS is local *(Tenure-mean)")
	replace
	mgroups("Panel A: OLS ", pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("Social" "Teachers" "Construction"  "EBR",nonumbers) nonumbers
	nolegend;
#delimit cr

*Add the within Rsquared
#delimit;
esttab  olsR2_2_social olsR2_2_teach olsR2_2_constr olsR2_2_EBR using "tables/tenure.tex", 
	keep(local)
	star(* .1 ** .05 *** .01) se
	brackets wrap label varwidth(22)
	append booktabs fragment
	stats(r2_w,fmt(2) labels("Within R-squared" ));
#delimit cr

*panel b iv
#delimit;
esttab iv_2_social iv_2_teach iv_2_constr iv_2_EBR using "tables/tenure.tex", 
	keep(local interaction tenure0)
	stats(N ,fmt(0 ) labels("Number of observations" )) 
	star(* .1 ** .05 *** .01) se 
	scalars("Controls")
	wrap fragment booktabs 
	coeflabels(local60 "PS is local" tenure0 "Tenure" interaction "PS is local *(Tenure-mean)")
	append
	mgroups("Panel B: IV ", pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("Social" "Teachers" "Construction"  "EBR",nonumbers) nonumbers
	nolegend;
#delimit cr



****************************************************************
***Table A8: Interaction with tenure
****************************************************************

*(See Table 5 above)




**************************************************************************************
*** TABLE A9: IMPACT OF GENERAL SECRETARY WORK EXPERIENCE ON PROVINCIAL GOVERNANCE
**************************************************************************************

use "data/analysis.dta", clear

estimates clear
eststo clear

global controls "age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I*"

local dependent "social teach constr EBR"

foreach depvar in `dependent' {

qui ivreg2 `depvar' GS_work a_groXtime* $controls if local==0, cluster(prov_nr clustvar2)
eststo
qui estadd local Controls "All"

local icont=`icont'+1

}
*

label var GS_work "General secretary worked in province"

** Table using standard errors from ivreg2, but with F stat calculated by the cluster2 command
#delimit;
esttab est1 est2 est3 est4 using "tables/GS_worked.tex", 
	keep(GS_work)
	star(* .1 ** .05 *** .01) se
	wrap label varwidth(22)
	replace booktabs fragment
	scalars("Controls")
	stats(N ,fmt(0) labels("Number of observations"))
	mgroups("OLS, sub-sample of PS - outsider" , pattern(1 0 0 0 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	mlabel("Social" "Teachers" "Construction"  "EBR",nonumbers);
#delimit cr



