*cd "" 


****************************************************************
***Table A5, rows that begin with "Wild cluster..."
****************************************************************





****************************************************************
***bootstrap social: OLS 
****************************************************************

#delimit ;

version 9.0 ;

clear ;
set mem 5m ;
set more off ;
set seed 365476247 ;

cap prog drop runme ;
prog def runme ;

tempfile main bootsave ;

use analysis.dta, clear;
rename local local60;

global controls age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I* ;

di ;
*run ols and cluster at the province level ;
qui ivreg2 social local60 a_groXtime*  $controls, cluster(prov_nr) ; 

* save t-test as a global variable ;
global mainbeta = _b[local60] ;
global maint = (_b[local60]) / _se[local60] ;
predict epshat , resid;
predict yhat , xb ;

/* also generate "impose the null hypothesis" yhat and residual */

* run ols and impose that _b[local60]=0 ;
qui ivreg2 social a_groXtime*  $controls, cluster(prov_nr) ; 

* output residuals ;
predict epshat_imposed , resid ;
predict yhat_imposed , xb ;

* sort by province and temp save data ;
sort prov_nr ;
qui save `main' , replace ;

* get the number of provinces ;
qui by prov_nr: keep if _n == 1 ;
keep prov_nr ;
qui summ ;
global numprov = r(N) ;
di r(N) ;

* output the t-statistics for local60 to a file ;

postfile bskeep t_wild
	using bs_results , replace ;


	
forvalues b = 1/$bootreps { ;

/* first, do wild cluster bootstrap */
use `main', replace ;

* with 50% probability constuct dummy ;
* that adds or substracts Radamaker error ;
qui by prov_nr: gen temp = uniform() ;
qui by prov_nr: gen pos = (temp[1] < .5) ;
gen wildresid = epshat_imposed * (2*pos - 1) ;

* now construct y ;
gen wildy = yhat_imposed + wildresid ;

* now regress y on all x variables ;
qui ivreg2 wildy  $controls a_groXtime* local60, cluster(prov_nr) ;
*qui reg wildy  $controls a_groXtime* local60, cluster(prov_nr) ;

* generate the t-stat ;
local bst_wild = _b[local60] / _se[local60]  ;
*local bst_wild = (_b[local60] - $mainbeta) / _se[local60] ;

* add to the bottom of the post file ;
post bskeep (`bst_wild') ;

} ; /* end of bootstrap reps */

* save the post file ;
postclose bskeep ;

* clear the current data set ;
clear ;

* load up the wild t-stats ;
use bs_results ;

* figure out where the main-t is in the synthetic distribution ;

gen positive=$maint>0 ;
gen pos=t_wild>$maint ;
gen neg=t_wild<$maint ;
gen reject=positive*pos + (1-positive)*neg ;
sum reject ;
local sumreject=r(sum) ;
local p_value_wild=2*`sumreject'/$bootreps ;

di "Number BS reps = $bootreps" ;
di "P-value from wild boostrap = `p_value_wild'" ;


end ;

global bootreps = 999 ;
runme .04 ;



****************************************************************
***bootstrap social: RF 
****************************************************************

#delimit ;

version 9.0 ;

clear ;
set mem 5m ;
set more off ;
set seed 365476247 ;

cap prog drop runme ;
prog def runme ;

tempfile main bootsave ;

use analysis.dta, clear;
rename local local60;
rename instr2 x20;
global controls age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I* ;

di ;
*run ols and cluster at the province level ;
qui ivreg2 social x20 a_groXtime*  $controls, cluster(prov_nr) ; 

* save t-test as a global variable ;
global mainbeta = _b[x20] ;
global maint = (_b[x20]) / _se[x20] ;
predict epshat , resid;
predict yhat , xb ;

/* also generate "impose the null hypothesis" yhat and residual */

* run ols and impose that _b[x20]=0 ;
qui ivreg2 social a_groXtime*  $controls, cluster(prov_nr) ; 

* output residuals ;
predict epshat_imposed , resid ;
predict yhat_imposed , xb ;

* sort by province and temp save data ;
sort prov_nr ;
qui save `main' , replace ;

* get the number of provinces ;
qui by prov_nr: keep if _n == 1 ;
keep prov_nr ;
qui summ ;
global numprov = r(N) ;
di r(N) ;

postfile bskeep t_wild
	using bs_results , replace ;

forvalues b = 1/$bootreps { ;

/* first, do wild cluster bootstrap */
use `main', replace ;

* with 50% probability constuct dummy ;
* that adds or substracts Radamaker error ;
qui by prov_nr: gen temp = uniform() ;
qui by prov_nr: gen pos = (temp[1] < .5) ;
gen wildresid = epshat_imposed * (2*pos - 1) ;

* now construct y ;
gen wildy = yhat_imposed + wildresid ;

* now regress y on all x variables ;
qui ivreg2 wildy  $controls a_groXtime* x20, cluster(prov_nr) ;
*qui reg wildy  $controls a_groXtime* x20, cluster(prov_nr) ;

* generate the t-stat ;
local bst_wild = _b[x20] / _se[x20]  ;
*local bst_wild = (_b[local60] - $mainbeta) / _se[local60] ;

* add to the bottom of the post file ;
post bskeep (`bst_wild') ;


} ; /* end of bootstrap reps */

* save the post file ;
postclose bskeep ;

* clear the current data set ;
clear ;

* load up the wild t-stats ;
use bs_results ;

* figure out where the main-t is in the synthetic distribution ;

gen positive=$maint>0 ;
gen pos=t_wild>$maint ;
gen neg=t_wild<$maint ;
gen reject=positive*pos + (1-positive)*neg ;
sum reject ;
local sumreject=r(sum) ;
local p_value_wild=2*`sumreject'/$bootreps ;

di "Number BS reps = $bootreps" ;
di "P-value from wild boostrap = `p_value_wild'" ;
*log close ;


end ;

global bootreps = 999 ;
runme .04 ;

****************************************************************
***bootstrap teach: OLS 
****************************************************************

#delimit ;

version 9.0 ;

clear ;
set mem 5m ;
set more off ;
set seed 365476247 ;

cap prog drop runme ;
prog def runme ;

tempfile main bootsave ;

use analysis.dta, clear;
rename local local60;
global controls age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I* ;

di ;
*run ols and cluster at the province level ;
qui ivreg2 teach local60 a_groXtime*  $controls, cluster(prov_nr) ; 

* save t-test as a global variable ;
global mainbeta = _b[local60] ;
global maint = (_b[local60]) / _se[local60] ;
predict epshat , resid;
predict yhat , xb ;

/* also generate "impose the null hypothesis" yhat and residual */

* run ols and impose that _b[local60]=0 ;
qui ivreg2 teach a_groXtime*  $controls, cluster(prov_nr) ; 

* output residuals ;
predict epshat_imposed , resid ;
predict yhat_imposed , xb ;

* sort by province and temp save data ;
sort prov_nr ;
qui save `main' , replace ;

* get the number of provinces ;
qui by prov_nr: keep if _n == 1 ;
keep prov_nr ;
qui summ ;
global numprov = r(N) ;
di r(N) ;

postfile bskeep t_wild
	using bs_results , replace ;

forvalues b = 1/$bootreps { ;

/* first, do wild cluster bootstrap */
use `main', replace ;

* with 50% probability constuct dummy ;
* that adds or substracts Radamaker error ;
qui by prov_nr: gen temp = uniform() ;
qui by prov_nr: gen pos = (temp[1] < .5) ;
gen wildresid = epshat_imposed * (2*pos - 1) ;

* now construct y ;
gen wildy = yhat_imposed + wildresid ;

* now regress y on all x variables ;
qui ivreg2 wildy  $controls a_groXtime* local60, cluster(prov_nr) ;

* generate the t-stat ;
local bst_wild = _b[local60] / _se[local60]  ;

* add to the bottom of the post file ;
post bskeep (`bst_wild') ;

} ; /* end of bootstrap reps */

* save the post file ;
postclose bskeep ;

* clear the current data set ;
clear ;

* load up the wild t-stats ;
use bs_results ;

* figure out where the main-t is in the synthetic distribution ;

gen positive=$maint>0 ;
gen pos=t_wild>$maint ;
gen neg=t_wild<$maint ;
gen reject=positive*pos + (1-positive)*neg ;
sum reject ;
local sumreject=r(sum) ;
local p_value_wild=2*`sumreject'/$bootreps ;

di "Number BS reps = $bootreps" ;
di "P-value from wild boostrap = `p_value_wild'" ;
*log close ;


end ;

global bootreps = 999 ;
runme .04 ;



****************************************************************
***bootstrap teach: RF 
****************************************************************

#delimit ;

version 9.0 ;

clear ;
set mem 5m ;
set more off ;
set seed 365476247 ;

cap prog drop runme ;
prog def runme ;

tempfile main bootsave ;

use analysis.dta, clear;
rename local local60;
rename instr2 x20;

global controls age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I* ;

di ;
*run ols and cluster at the province level ;
qui ivreg2 teach x20 a_groXtime*  $controls, cluster(prov_nr) ; 

* save t-test as a global variable ;
global mainbeta = _b[x20] ;
global maint = (_b[x20]) / _se[x20] ;
predict epshat , resid;
predict yhat , xb ;

/* also generate "impose the null hypothesis" yhat and residual */

* run ols and impose that _b[x20]=0 ;
qui ivreg2 teach a_groXtime*  $controls, cluster(prov_nr) ; 

* output residuals ;
predict epshat_imposed , resid ;
predict yhat_imposed , xb ;

* sort by province and temp save data ;
sort prov_nr ;
qui save `main' , replace ;

* get the number of provinces ;
qui by prov_nr: keep if _n == 1 ;
keep prov_nr ;
qui summ ;
global numprov = r(N) ;
di r(N) ;

* output the t-statistics for local60 to a file ;

postfile bskeep t_wild
	using bs_results , replace ;

forvalues b = 1/$bootreps { ;

/* first, do wild cluster bootstrap */
use `main', replace ;

* with 50% probability constuct dummy ;
* that adds or substracts Radamaker error ;
qui by prov_nr: gen temp = uniform() ;
qui by prov_nr: gen pos = (temp[1] < .5) ;
gen wildresid = epshat_imposed * (2*pos - 1) ;

* now construct y ;
gen wildy = yhat_imposed + wildresid ;

* now regress y on all x variables ;
qui ivreg2 wildy  $controls a_groXtime* x20, cluster(prov_nr) ;

* generate the t-stat ;
local bst_wild = _b[x20] / _se[x20]  ;
*local bst_wild = (_b[local60] - $mainbeta) / _se[local60] ;

* add to the bottom of the post file ;
post bskeep (`bst_wild') ;

} ; /* end of bootstrap reps */

* save the post file ;
postclose bskeep ;

* clear the current data set ;
clear ;

* load up the wild t-stats ;
use bs_results ;

* figure out where the main-t is in the synthetic distribution ;

gen positive=$maint>0 ;
gen pos=t_wild>$maint ;
gen neg=t_wild<$maint ;
gen reject=positive*pos + (1-positive)*neg ;
sum reject ;
local sumreject=r(sum) ;
local p_value_wild=2*`sumreject'/$bootreps ;

di "Number BS reps = $bootreps" ;
di "P-value from wild boostrap = `p_value_wild'" ;


end ;

global bootreps = 999 ;
runme .04 ;


****************************************************************
***bootstrap constr: OLS 
****************************************************************

#delimit ;

version 9.0 ;

clear ;
set mem 5m ;
set more off ;
set seed 365476247 ;

cap prog drop runme ;
prog def runme ;

tempfile main bootsave ;

use analysis.dta, clear;
rename local local60;
global controls age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I* ;

di ;
qui ivreg2 constr local60 a_groXtime*  $controls, cluster(prov_nr) ; 

* save t-test as a global variable ;
global mainbeta = _b[local60] ;
global maint = (_b[local60]) / _se[local60] ;
predict epshat , resid;
predict yhat , xb ;

/* also generate "impose the null hypothesis" yhat and residual */

* run ols and impose that _b[local60]=0 ;
qui ivreg2 constr a_groXtime*  $controls, cluster(prov_nr) ; 

* output residuals ;
predict epshat_imposed , resid ;
predict yhat_imposed , xb ;

* sort by province and temp save data ;
sort prov_nr ;
qui save `main' , replace ;

* get the number of provinces ;
qui by prov_nr: keep if _n == 1 ;
keep prov_nr ;
qui summ ;
global numprov = r(N) ;
di r(N) ;

postfile bskeep t_wild
	using bs_results , replace ;

forvalues b = 1/$bootreps { ;

/* first, do wild cluster bootstrap */
use `main', replace ;

* with 50% probability constuct dummy ;
* that adds or substracts Radamaker error ;
qui by prov_nr: gen temp = uniform() ;
qui by prov_nr: gen pos = (temp[1] < .5) ;
gen wildresid = epshat_imposed * (2*pos - 1) ;

* now construct y ;
gen wildy = yhat_imposed + wildresid ;

* now regress y on all x variables ;
qui ivreg2 wildy  $controls a_groXtime* local60, cluster(prov_nr) ;

* generate the t-stat ;
local bst_wild = _b[local60] / _se[local60]  ;
*local bst_wild = (_b[local60] - $mainbeta) / _se[local60] ;

* add to the bottom of the post file ;
post bskeep (`bst_wild') ;

} ; /* end of bootstrap reps */

* save the post file ;
postclose bskeep ;

* clear the current data set ;
clear ;

* load up the wild t-stats ;
use bs_results ;

* figure out where the main-t is in the synthetic distribution ;

gen positive=$maint>0 ;
gen pos=t_wild>$maint ;
gen neg=t_wild<$maint ;
gen reject=positive*pos + (1-positive)*neg ;
sum reject ;
local sumreject=r(sum) ;
local p_value_wild=2*`sumreject'/$bootreps ;

di "Number BS reps = $bootreps" ;
di "P-value from wild boostrap = `p_value_wild'" ;


end ;

global bootreps = 999 ;
runme .04 ;



****************************************************************
***bootstrap constr: RF 
****************************************************************

#delimit ;

version 9.0 ;

clear ;
set mem 5m ;
set more off ;
set seed 365476247 ;

cap prog drop runme ;
prog def runme ;

tempfile main bootsave ;

use analysis.dta, clear;
rename local local60;
rename instr2 x20;

global controls age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I* ;

di ;
*run ols and cluster at the province level ;
qui ivreg2 constr x20 a_groXtime*  $controls, cluster(prov_nr) ; 

* save t-test as a global variable ;
global mainbeta = _b[x20] ;
global maint = (_b[x20]) / _se[x20] ;
predict epshat , resid;
predict yhat , xb ;

/* also generate "impose the null hypothesis" yhat and residual */

* run ols and impose that _b[x20]=0 ;
qui ivreg2 constr a_groXtime*  $controls, cluster(prov_nr) ; 

* output residuals ;
predict epshat_imposed , resid ;
predict yhat_imposed , xb ;

* sort by province and temp save data ;
sort prov_nr ;
qui save `main' , replace ;

* get the number of provinces ;
qui by prov_nr: keep if _n == 1 ;
keep prov_nr ;
qui summ ;
global numprov = r(N) ;
di r(N) ;

* output the t-statistics for local60 to a file ;

postfile bskeep t_wild
	using bs_results , replace ;

forvalues b = 1/$bootreps { ;

/* first, do wild cluster bootstrap */
use `main', replace ;

* with 50% probability constuct dummy ;
* that adds or substracts Radamaker error ;
qui by prov_nr: gen temp = uniform() ;
qui by prov_nr: gen pos = (temp[1] < .5) ;
gen wildresid = epshat_imposed * (2*pos - 1) ;

* now construct y ;
gen wildy = yhat_imposed + wildresid ;

* now regress y on all x variables ;
qui ivreg2 wildy  $controls a_groXtime* x20, cluster(prov_nr) ;

* generate the t-stat ;
local bst_wild = _b[x20] / _se[x20]  ;

* add to the bottom of the post file ;
post bskeep (`bst_wild') ;

} ; /* end of bootstrap reps */

* save the post file ;
postclose bskeep ;

* clear the current data set ;
clear ;

* load up the wild t-stats ;
use bs_results ;

* figure out where the main-t is in the synthetic distribution ;

gen positive=$maint>0 ;
gen pos=t_wild>$maint ;
gen neg=t_wild<$maint ;
gen reject=positive*pos + (1-positive)*neg ;
sum reject ;
local sumreject=r(sum) ;
local p_value_wild=2*`sumreject'/$bootreps ;

di "Number BS reps = $bootreps" ;
di "P-value from wild boostrap = `p_value_wild'" ;


end ;

global bootreps = 999 ;
runme .04 ;



****************************************************************
***bootstrap EBR: OLS 
****************************************************************

#delimit ;

version 9.0 ;

clear ;
set mem 5m ;
set more off ;
set seed 365476247 ;

cap prog drop runme ;
prog def runme ;

tempfile main bootsave ;

use analysis.dta, clear;
rename local local60;
global controls age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I* ;

di ;
*run ols and cluster at the province level ;
qui ivreg2 EBR local60 a_groXtime*  $controls, cluster(prov_nr) ; 

* save t-test as a global variable ;
global mainbeta = _b[local60] ;
global maint = (_b[local60]) / _se[local60] ;
predict epshat , resid;
predict yhat , xb ;

/* also generate "impose the null hypothesis" yhat and residual */

* run ols and impose that _b[local60]=0 ;
qui ivreg2 EBR a_groXtime*  $controls, cluster(prov_nr) ; 

* output residuals ;
predict epshat_imposed , resid ;
predict yhat_imposed , xb ;

* sort by province and temp save data ;
sort prov_nr ;
qui save `main' , replace ;

* get the number of provinces ;
qui by prov_nr: keep if _n == 1 ;
keep prov_nr ;
qui summ ;
global numprov = r(N) ;
di r(N) ;

postfile bskeep t_wild
	using bs_results , replace ;

forvalues b = 1/$bootreps { ;

/* first, do wild cluster bootstrap */
use `main', replace ;

* with 50% probability constuct dummy ;
* that adds or substracts Radamaker error ;
qui by prov_nr: gen temp = uniform() ;
qui by prov_nr: gen pos = (temp[1] < .5) ;
gen wildresid = epshat_imposed * (2*pos - 1) ;

* now construct y ;
gen wildy = yhat_imposed + wildresid ;

* now regress y on all x variables ;
qui ivreg2 wildy  $controls a_groXtime* local60, cluster(prov_nr) ;

* generate the t-stat ;
local bst_wild = _b[local60] / _se[local60]  ;

* add to the bottom of the post file ;
post bskeep (`bst_wild') ;

} ; /* end of bootstrap reps */

* save the post file ;
postclose bskeep ;

* clear the current data set ;
clear ;

* load up the wild t-stats ;
use bs_results ;

* figure out where the main-t is in the synthetic distribution ;

gen positive=$maint>0 ;
gen pos=t_wild>$maint ;
gen neg=t_wild<$maint ;
gen reject=positive*pos + (1-positive)*neg ;
sum reject ;
local sumreject=r(sum) ;
local p_value_wild=2*`sumreject'/$bootreps ;

di "Number BS reps = $bootreps" ;
di "P-value from wild boostrap = `p_value_wild'" ;


end ;

global bootreps = 999 ;
runme .04 ;



****************************************************************
***bootstrap EBR: RF 
****************************************************************

#delimit ;

version 9.0 ;

clear ;
set mem 5m ;
set more off ;
set seed 365476247 ;

cap prog drop runme ;
prog def runme ;

tempfile main bootsave ;

use analysis.dta, clear;
rename local local60;
rename instr2 x20;

global controls age0 tenure0 higedu0 home_started20 age_limit_enf0 second_term_same_pos0 center_high0 politburo0 mrr pop_tot urbanization GRP_lg  prev_perf0 average_dGRP0 _I* ;

di ;
*run ols and cluster at the province level ;
qui ivreg2 EBR x20 a_groXtime*  $controls, cluster(prov_nr) ; 

* save t-test as a global variable ;
global mainbeta = _b[x20] ;
global maint = (_b[x20]) / _se[x20] ;
predict epshat , resid;
predict yhat , xb ;

/* also generate "impose the null hypothesis" yhat and residual */

* run ols and impose that _b[x20]=0 ;
qui ivreg2 EBR a_groXtime*  $controls, cluster(prov_nr) ; 

* output residuals ;
predict epshat_imposed , resid ;
predict yhat_imposed , xb ;

* sort by province and temp save data ;
sort prov_nr ;
qui save `main' , replace ;

* get the number of provinces ;
qui by prov_nr: keep if _n == 1 ;
keep prov_nr ;
qui summ ;
global numprov = r(N) ;
di r(N) ;

* output the t-statistics for local60 to a file ;

postfile bskeep t_wild
	using bs_results , replace ;

forvalues b = 1/$bootreps { ;

/* first, do wild cluster bootstrap */
use `main', replace ;

* with 50% probability constuct dummy ;
* that adds or substracts Radamaker error ;
qui by prov_nr: gen temp = uniform() ;
qui by prov_nr: gen pos = (temp[1] < .5) ;
gen wildresid = epshat_imposed * (2*pos - 1) ;

* now construct y ;
gen wildy = yhat_imposed + wildresid ;

* now regress y on all x variables ;
qui ivreg2 wildy  $controls a_groXtime* x20, cluster(prov_nr) ;

* generate the t-stat ;
local bst_wild = _b[x20] / _se[x20]  ;

* add to the bottom of the post file ;
post bskeep (`bst_wild') ;

} ; /* end of bootstrap reps */

* save the post file ;
postclose bskeep ;

* clear the current data set ;
clear ;

* load up the wild t-stats ;
use bs_results ;

* figure out where the main-t is in the synthetic distribution ;

gen positive=$maint>0 ;
gen pos=t_wild>$maint ;
gen neg=t_wild<$maint ;
gen reject=positive*pos + (1-positive)*neg ;
sum reject ;
local sumreject=r(sum) ;
local p_value_wild=2*`sumreject'/$bootreps ;

di "Number BS reps = $bootreps" ;
di "P-value from wild boostrap = `p_value_wild'" ;


end ;

global bootreps = 999 ;
runme .04 ;
